Module dev

Module dev 

Structs

AndThen
Service for the and_then combinator, chaining a computation onto the end of another service which completes successfully.
AndThenFactory
.and_then() service factory combinator
Apply
Apply service combinator
ApplyCtx
ApplyFactory
apply() service factory
ApplyMiddleware
Apply middleware to a service factory.
FnFactory
ServiceFactory for a AsyncFn(&St) -> Result<Srv, Err> function
FnMiddleware
FnMiddleware service combinator
FnReadiness
Function that can act as a ready call.
FnService
Service implementation for an AsyncFn(Req) -> Result<Res, Err> fn.
FnServiceSt
Service implementation for an AsyncFn(Req, &St) -> Result<Res, Err> function.
FnServiceStFactory
FnShutdown
Function that can act as a on_shutdown callback.
Map
Service for the map combinator, changing the type of a service’s response.
MapErr
Service for the map_err combinator, changing the type of a service’s error.
MapErrFactory
Factory for the map_err combinator, changing the type of a new service’s error.
MapFactory
MapNewService new service combinator
MapInitErr
MapInitError service combinator
MapState
Map state for inner service
MapStateFactory
Factory for map state for inner service
ServiceChain
Chain builder - chain allows to compose multiple service into one service.
ServiceChainFactory
Service factory builder
Then
Service for the then combinator, chaining a computation onto the end of another service.
ThenFactory
.then() service factory combinator