pub struct SharedCfg(/* private fields */);Expand description
An immutable collection of typed configuration values.
Implementations
Sourcepub fn new(tag: &'static str) -> SharedCfgBuilder
pub fn new(tag: &'static str) -> SharedCfgBuilder
Starts building a shared configuration with the given tag.
Sourcepub fn get<T>(&self) -> Cfg<T>where
T: Configuration,
pub fn get<T>(&self) -> Cfg<T>where
T: Configuration,
Returns the configuration value of type T.
Panics
Panics if the shared configuration is still being built.