ServiceChainFactory

Struct ServiceChainFactory 

pub struct ServiceChainFactory<Sf, St, Req> { /* private fields */ }
Service factory builder

Implementations

Source

impl<Sf: ServiceFactory<St, Req>, St, Req> ServiceChainFactory<Sf, St, Req>

pub fn and_then<U>( self, factory: impl IntoServiceFactory<U, St, Sf::Res>, ) -> ServiceChainFactory<AndThenFactory<Sf, U>, St, Req>
where Self: Sized, U: ServiceFactory<St, Sf::Res, Error = Sf::Error, InitError = Sf::InitError>,

Call another service after call to this one has resolved successfully.

pub fn apply<U>( self, tr: U, ) -> ServiceChainFactory<ApplyMiddleware<U, Sf>, St, Req>
where U: Middleware<Sf::Service, St>,

Apply Middleware to current service factory.

Short version of apply(middleware, factory(...))

pub fn apply_fn<F, In, Out, Err>( self, f: F, ) -> ServiceChainFactory<ApplyFactory<F, Sf, St, Req, In, Out, Err>, St, In>
where F: AsyncFn(In, &ApplyCtx<'_, Sf::Service, St, Req>) -> Result<Out, Err> + Clone, Err: From<Sf::Error>,

Apply function middleware to current service factory.

Short version of apply_fn_factory(factory(...), fn)

pub fn then<F, U>( self, factory: F, ) -> ServiceChainFactory<ThenFactory<Sf, U>, St, Req>
where Self: Sized, F: IntoServiceFactory<U, St, Result<Sf::Res, Sf::Error>>, U: ServiceFactory<St, Result<Sf::Res, Sf::Error>, Error = Sf::Error, InitError = Sf::InitError>,

Create chain factory to chain on a computation for when a call to the service finished, passing the result of the call to the next service U.

Note that this function consumes the receiving factory and returns a wrapped version of it.

pub fn map<F, Res>( self, f: F, ) -> ServiceChainFactory<MapFactory<F, Sf, Res>, St, Req>
where Self: Sized, F: Fn(Sf::Res) -> Res + Clone,

Map this service’s output to a different type, returning a new service of the resulting type.

pub fn map_err<F, E>( self, f: F, ) -> ServiceChainFactory<MapErrFactory<F, Sf, E>, St, Req>
where Self: Sized, F: Fn(Sf::Error) -> E + Clone,

Map this service’s error to a different error.

pub fn map_init_err<F, E>( self, f: F, ) -> ServiceChainFactory<MapInitErr<F, Sf, E>, St, Req>
where Self: Sized, F: Fn(Sf::InitError) -> E + Clone,

Map this factory’s init error to a different error, returning a new factory.

pub fn readiness<F>( self, ready: F, ) -> ServiceChainFactory<AndThenFactory<Sf, FnReadiness<F, Sf::Error>>, St, Req>
where Self: Sized, F: AsyncFn(&St) -> Result<(), Sf::Error> + Clone,

Add custom readiness check to the service factory.

pub fn shutdown<F>( self, sh: F, ) -> ServiceChainFactory<AndThenFactory<Sf, FnShutdown<F, Sf::Error>>, St, Req>
where Self: Sized, F: AsyncFnOnce(&St) + Clone,

Add custom shutdown callback to the service factory.

pub async fn pipeline( &self, st: St, ) -> Result<Pipeline<Req, Sf::Res, Sf::Error>, Sf::InitError>
where Sf: 'static, St: 'static, Req: 'static,

Create and return a new service value asynchronously and wrap into a container