pub struct ServiceChainFactory<Sf, St, Req> { /* private fields */ }Expand description
Service factory builder
Implementations
Sourceimpl<Sf: ServiceFactory<St, Req>, St, Req> ServiceChainFactory<Sf, St, Req>
impl<Sf: ServiceFactory<St, Req>, St, Req> ServiceChainFactory<Sf, St, Req>
Sourcepub fn and_then<U>(
self,
factory: impl IntoServiceFactory<U, St, Sf::Res>,
) -> ServiceChainFactory<AndThenFactory<Sf, U>, St, Req>
pub fn and_then<U>( self, factory: impl IntoServiceFactory<U, St, Sf::Res>, ) -> ServiceChainFactory<AndThenFactory<Sf, U>, St, Req>
Call another service after call to this one has resolved successfully.
Sourcepub fn apply<U>(
self,
tr: U,
) -> ServiceChainFactory<ApplyMiddleware<U, Sf>, St, Req>where
U: Middleware<Sf::Service, St>,
pub fn apply<U>(
self,
tr: U,
) -> ServiceChainFactory<ApplyMiddleware<U, Sf>, St, Req>where
U: Middleware<Sf::Service, St>,
Apply Middleware to current service factory.
Short version of apply(middleware, factory(...))
Sourcepub fn apply_fn<F, In, Out, Err>(
self,
f: F,
) -> ServiceChainFactory<ApplyFactory<F, Sf, St, Req, In, Out, Err>, St, In>
pub fn apply_fn<F, In, Out, Err>( self, f: F, ) -> ServiceChainFactory<ApplyFactory<F, Sf, St, Req, In, Out, Err>, St, In>
Apply function middleware to current service factory.
Short version of apply_fn_factory(factory(...), fn)
Sourcepub fn then<F, U>(
self,
factory: F,
) -> ServiceChainFactory<ThenFactory<Sf, U>, St, Req>
pub fn then<F, U>( self, factory: F, ) -> ServiceChainFactory<ThenFactory<Sf, U>, St, Req>
Create chain factory to chain on a computation for when a call to the
service finished, passing the result of the call to the next
service U.
Note that this function consumes the receiving factory and returns a wrapped version of it.
Sourcepub fn map<F, Res>(
self,
f: F,
) -> ServiceChainFactory<MapFactory<F, Sf, Res>, St, Req>
pub fn map<F, Res>( self, f: F, ) -> ServiceChainFactory<MapFactory<F, Sf, Res>, St, Req>
Map this service’s output to a different type, returning a new service of the resulting type.
Sourcepub fn map_err<F, E>(
self,
f: F,
) -> ServiceChainFactory<MapErrFactory<F, Sf, E>, St, Req>
pub fn map_err<F, E>( self, f: F, ) -> ServiceChainFactory<MapErrFactory<F, Sf, E>, St, Req>
Map this service’s error to a different error.
Sourcepub fn map_init_err<F, E>(
self,
f: F,
) -> ServiceChainFactory<MapInitErr<F, Sf, E>, St, Req>
pub fn map_init_err<F, E>( self, f: F, ) -> ServiceChainFactory<MapInitErr<F, Sf, E>, St, Req>
Map this factory’s init error to a different error, returning a new factory.
Sourcepub fn readiness<F>(
self,
ready: F,
) -> ServiceChainFactory<AndThenFactory<Sf, FnReadiness<F, Sf::Error>>, St, Req>
pub fn readiness<F>( self, ready: F, ) -> ServiceChainFactory<AndThenFactory<Sf, FnReadiness<F, Sf::Error>>, St, Req>
Add custom readiness check to the service factory.
Sourcepub fn shutdown<F>(
self,
sh: F,
) -> ServiceChainFactory<AndThenFactory<Sf, FnShutdown<F, Sf::Error>>, St, Req>
pub fn shutdown<F>( self, sh: F, ) -> ServiceChainFactory<AndThenFactory<Sf, FnShutdown<F, Sf::Error>>, St, Req>
Add custom shutdown callback to the service factory.